---
title: KSNET 상점아이디 추가 절차
category: 결제서비스 (채널설정 및 이용안내) > 이용안내 > 서비스 추가/변경
seo:
  title: KSNET 상점아이디추가
  description: >-
    KSNET의 상점아이디(사이트코드) 추가절차 안내입니다. 추가 상점아이디는 포트원 호스팅사를 기준으로 수수료가 적용되며, 상점아이디를
    추가하실 수 있는 경우를 확인하세요.
  keywords:
    - KSNET
    - 서비스추가/변경
tags:
  - KSNET
  - 서비스추가/변경
pgCompanies:
  - KSNET
searchTags:
  - MID 추가
  - MID추가
  - 사이트 추가
  - 사이트추가
  - 서비스추가
  - 서비스 추가
  - 케이에스넷 MID
  - 케이에스넷 상점아이디
  - 상점아이디
  - MID
  - KSNET MID
datetime: 2024-01-25T15:00:00.000Z
---

<Callout content="KSNET 상점아이디 추가 절차를 안내해드립니다. 추가되는 상점아이디는 포트원 호스팅사를 기준으로 수수료가 적용되는 점 참고해주세요." />

<Callout title="포트원 기준 결제대행사 수수료 보러가기↗" />

### **상점아이디 추가 케이스**

<Callout content="포트원 정책에 의하여 기존에 포트원을 통하지 않고 계약된 상점아이디는 포트원 서비스 사용이 불가합니다. 새로운 포트원용 상점아이디를 추가 발급 받으신 후 이용해주시기 바랍니다." title="참고사항" icon="💡" />

- 이미 KSNET과 직접 계약이 되어있다가 포트원으로 연동하고자 하시는 경우
- 다른 호스팅사를 통해 KSNET과 계약 되어있다가 포트원으로 연동하시는 경우
- 새로운 서비스가 추가되는 경우 (=심사를 다시 받아야 하는 경우)
- 기존 서비스와 결제/정산을 분리하고자 하시는 경우
- 심사받은 적 없는 연동방식을 추가하시는 경우 (ex. 일반결제 사용중에 정기결제 추가시)

### **신청방법**

#### **신청 경로**

아래 작성 내용을 참고하여 관련 내용을 포트원 고객지원팀으로 전달주시면 KSNET측으로 전달드리겠습니다. KSNET 계약부서에서 내용 확인 후 필요한 절차를 2\~3영업일 내 담당자님께 직접 메일 안내드릴 예정입니다.

- 포트원 고객지원  : [cs@portone.io↗](mailto:cs@portone.io)

#### **전달 내용**

- 상호명 :
- 사업자번호 :
- 대표자명 :
- 포트원을 통해 연동하실 서비스(사이트 또는 앱다운로드) 주소 :
- 포트원을 통해 연동하실 서비스 유형(업종) :
- 고객사 담당자 정보 : 성함 / 연락처 / 이메일주소
- 기존에 이용중이셨던 KSNET 상점아이디(MID) :
- 기존 상점아이디의 결제수수료율 (결제수단별 기재필요) :
  - 기존에도 포트원을 통해 서비스 이용중이셨다면 전달주지 않으셔도 됩니다.
  - 카드의 경우 적용중인 **영중소 구분**까지 반드시 적어주시기 바랍니다.\
    [영중소 수수료율 기준 보러가기↗](https://help.portone.io/content/small-business-commission-fee)
- 원하시는 결제 방식 (ex. 일반결제, 정기결제, 수기결제) :
- 원하시는 결제 수단 (ex. 카드, 계좌이체, 휴대폰결제) :
